@@ -10,11 +10,14 @@ from .junit_xml_grader import JUnitXMLGrader
 from .bitwise_json_grader import BitwiseJSONGrader
 from .circuitsim_grader import CircuitSimGrader
 from .pylc3_grader import PyLC3Grader
+from .multi_command_grader import MultiCommandGrader
+from .python_module_grader import PythonModuleGrader
 
 __all__ = ['InvalidGraderConfigError', 'GraderInterface', 'Part',
            'ThreadedGrader', 'PromptGrader', 'OpenFileGrader', 'CommandGrader',
            'LibcheckGrader', 'JUnitJSONGrader', 'JUnitXMLGrader',
-           'BitwiseJSONGrader', 'CircuitSimGrader', 'PyLC3Grader']
+           'BitwiseJSONGrader', 'CircuitSimGrader', 'PyLC3Grader',
+           'MultiCommandGrader', 'PythonModuleGrader']
 
 _GRADERS = (
     PromptGrader,
@@ -26,5 +29,7 @@ _GRADERS = (
     BitwiseJSONGrader,
     CircuitSimGrader,
     PyLC3Grader,
+    MultiCommandGrader,
+    PythonModuleGrader,
 )
 AVAILABLE_GRADERS = {cls.__name__: cls for cls in _GRADERS}
